var keyword_rename_c = require("keyword_rename_c");
keyword_rename_c._instanceof(1);
keyword_rename_c._finally(1);
keyword_rename_c._yield(0);
keyword_rename_c.yield = 0;
